.. Finchan documentation master file, created by
   sphinx-quickstart on Tue Jun 13 23:41:14 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Finchan's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   arch
   api
   extend
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
